Encoder

Struct Encoder 

pub struct Encoder<'a, W>
where W: Write,
{ /* private fields */ }
An LTX file encoder.

Example

let mut enc = litetx::Encoder::new(&mut w, &litetx::Header{
    flags: litetx::HeaderFlags::empty(),
    page_size: litetx::PageSize::new(4096).unwrap(),
    commit: litetx::PageNum::new(1).unwrap(),
    min_txid: litetx::TXID::ONE,
    max_txid: litetx::TXID::ONE,
    timestamp: SystemTime::now(),
    pre_apply_checksum: None,
}).expect("encoder");

let page_num = litetx::PageNum::new(1).unwrap();
enc.encode_page(page_num, &page).expect("encode_page");

enc.finish(page.page_checksum(page_num)).expect("finish");

Implementations

Source

impl<'a, W> Encoder<'a, W>
where W: Write,

pub fn new(w: W, hdr: &Header) -> Result<Encoder<'a, W>, Error>

Create a new Encoder that writes to w.

Depending on the hdr flags, the Encoder will produce either compressed or uncompressed LTX file.

pub fn encode_page( &mut self, page_num: PageNum, data: &[u8], ) -> Result<(), Error>

Encode a page with the given page_num and data.

Depending on the Header passed to Encoder::new, the following constraints are applied:

  • if min_txid is 1, the LTX file is considered to be a full snapshot of the database and must contain all pages from the first one up to commit in increasing oreder.
  • if min_txid is greater than 1, the LTX file may contain a subset of database pages in increasing order.
pub fn finish(self, post_apply_checksum: Checksum) -> Result<Trailer, Error>

Consume the encoder and write LTX trailer into the output.